pub enum MaskStrategy {
Redact,
PartialMask {
reveal_prefix: usize,
reveal_suffix: usize,
mask_char: char,
},
Hash {
salt: Option<String>,
},
Replace,
Encrypt {
key: String,
},
Custom(String),
}Expand description
How detected PII should be masked.
Examples
use cloakrs_core::MaskStrategy;
let strategy = MaskStrategy::PartialMask {
reveal_prefix: 1,
reveal_suffix: 4,
mask_char: '*',
};
assert!(matches!(strategy, MaskStrategy::PartialMask { .. }));Variants
Redact
Replace with a typed placeholder such as [EMAIL] or [SSN].
PartialMask
Preserve selected prefix and suffix characters while masking the middle.
Fields
Hash
Deterministic SHA-256 hash.
Replace
Replace with deterministic fake-but-safe data.
Encrypt
AES-256-GCM encryption.
Custom(String)
Replace every finding with this exact string.
Implementations
Sourceimpl MaskStrategy
impl MaskStrategy
Sourcepub fn replacement(&self, finding: &PiiEntity) -> String
pub fn replacement(&self, finding: &PiiEntity) -> String
Returns the replacement text for a finding.
Sourcepub fn try_replacement(&self, finding: &PiiEntity) -> Result<String>
pub fn try_replacement(&self, finding: &PiiEntity) -> Result<String>
Returns the replacement text for a finding, propagating fallible strategies.